@@ -46,7 +46,6 @@ setGeneric("getKEGGFrameData", function(x) standardGeneric("getKEGGFrameData"))
 
 setGeneric("GOID", function(object) standardGeneric("GOID")) 
 setGeneric("Term", function(object) standardGeneric("Term"))
-setGeneric("Ontology", function(object) standardGeneric("Ontology"))
 setGeneric("Definition", function(object) standardGeneric("Definition"))
 setGeneric("Synonym", function(object) standardGeneric("Synonym"))
 setGeneric("Secondary", function(object) standardGeneric("Secondary"))
@@ -62,6 +61,7 @@ setGeneric("Rtablename", function(x) standardGeneric("Rtablename"))
 setGeneric("Lfilter", function(x) standardGeneric("Lfilter"))
 setGeneric("Rfilter", function(x) standardGeneric("Rfilter"))
 setGeneric("flatten", function(x, ...) standardGeneric("flatten"))
+setGeneric("orgPackageName", function(x, ...) standardGeneric("orgPackageName"))
 
 ## AnnotationDb
 setGeneric("saveDb", signature="x",
