@@ -160,7 +160,7 @@ setMethod("show", "GOTerms",
 .attachGO <- function(con){
   GOLoc = system.file("extdata", "GO.sqlite", package="GO.db")
   attachSQL = paste0("ATTACH '", GOLoc, "' AS go;")
-  dbGetQuery(con, attachSQL)
+  dbAttach(con, attachSQL)
 }
 
 
@@ -221,10 +221,10 @@ setMethod("GOFrame", signature=signature(x="data.frame", organism="missing"), fu
   clnVals = frame
   sqlIns <- "INSERT INTO data (go_id, evidence, gene_id) VALUES (?,?,?)"
   dbBegin(con)
-  rset <- dbSendPreparedQuery(con, sqlIns, clnVals)
-  dbClearResult(rset)
-  dbCommit(con)
-
+  res <- dbSendQuery(con,sqlIns, params=unclass(unname(clnVals)))
+  dbClearResult(res)
+  dbCommit(con)  
+  
   ##Now I have to make a 'go_data' table from 'data' that to INSURE that all
   ##the GO IDs are also in GO.db...
   .attachGO(con)  
@@ -291,7 +291,7 @@ setMethod("getGOFrameData", "GOAllFrame", function(x){x@data})
 .attachKEGG <- function(con){
   KEGGLoc = system.file("extdata", "KEGG.sqlite", package="KEGG.db")
   attachSQL = paste0("ATTACH '", KEGGLoc, "' AS kegg;")
-  dbGetQuery(con, attachSQL)
+  dbAttach(con, attachSQL)
 }
 
 
