@@ -276,7 +276,7 @@ L2Rchain.colnames <- function(L2Rchain)
             altDB = dbList[i]
             altDBFile = system.file("extdata", paste0(altDB,".sqlite"), package=paste0(altDB,".db"))
             SQL <- paste0("ATTACH DATABASE '",altDBFile,"' AS ", .mangleDBName(altDB),";")
-            dbQuery(dbconn, SQL)
+            dbAttach(dbconn, SQL)
         }
 }
 
@@ -403,6 +403,11 @@ dbQuery <- function(conn, SQL, j0=NA)
         data0[[j0]]
 }
 
+dbAttach <- function(conn, SQL){
+    obj <- dbSendStatement(conn, SQL)
+    dbClearResult(obj)
+}
+
 dbGetTable <- function(conn, tablename, extra.SQL=NULL)
 {
     SQL <- paste0("SELECT * FROM ", tablename)
