@@ -445,7 +445,7 @@
   chipDb <- .getChipDbFile(y)
   chipSQL <- paste0("ATTACH '",chipDb,"' AS c")
   #message(chipSQL)
-  dbQuery(dbconn(x), chipSQL)
+  dbAttach(dbconn(x), chipSQL)
 }
 
 
@@ -573,7 +573,7 @@
   res <- dbQuery(dbconn(x), sql)
   ## then cleanup by doing a detach:
   if(exists("y", inherits=FALSE)){ ## I should not have to use inherits=FALSE?
-    dbQuery(dbconn(x), "DETACH DATABASE c")
+    dbAttach(dbconn(x), "DETACH DATABASE c")
   }
   ## then subset to only relevant cols
   res[,(colnames(res) %in% headerTables)]
@@ -917,6 +917,9 @@ testForValidKeytype <- function(x, keytype){
   if (!is.character(keys)){
       stop("'keys' must be a character vector")
   }
+  if (length(keys) == 0L) {
+      return()
+  }
   if(is.null(fks)){  ## Normally, fks is just NULL and so we will call keys()
       ktKeys <- keys(x, keytype)
   }else{             ## This lets the caller say wait: use these keys instead 
