@@ -10,7 +10,7 @@
 ## in the annotations etc.
 
 ##  library(AnnotationDbi);AnnotationDbi:::.test()
-
+require(RSQLite)
 require(org.Hs.eg.db)
 require(org.At.tair.db)
 require(org.Sc.sgd.db)
@@ -29,10 +29,12 @@ quiet <- suppressWarnings # quieten warnings from 1:many mappings in select()
 ## be reused elsewhere.
 test_generateExtraRows <- function(){
   ttab = data.frame(warpbreaks[1:10,])
+  ttab$breaks <- as.character(ttab$breaks)  
   tkeys = ttab$breaks
   tkeys = c(26, tkeys[1:7], tkeys[7], 30, tkeys[8:10], tkeys[10])
   res <- AnnotationDbi:::.generateExtraRows(ttab, tkeys, jointype='breaks')
-  checkTrue(length(tkeys) == dim(res)[1])
+  expLen <- sum(table(tkeys) * table(ttab$breaks))
+  checkTrue(expLen == dim(res)[1])
 }
 
 test_dropUnwantedRows <- function() {
@@ -67,7 +69,7 @@ test_dropUnwantedRows <- function() {
 }
 
 test_resort <- function() {
-    fun <- AnnotationDbi:::.resort
+    fun <- resort_base ## from AnnotationDbi
 
     ## repeat keys returned
     keys <- letters[1:5]
